@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application
 
 package App::Cme::Command::edit ;
-$App::Cme::Command::edit::VERSION = '1.007';
+$App::Cme::Command::edit::VERSION = '1.008';
 use strict;
 use warnings;
 use 5.10.1;
@@ -38,7 +38,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application] [file | ~~ ] [ -ui tk|curses|shell ] [ -open-item xxx ] ";
+  return "$desc [application] [ file ] [ -ui tk|curses|shell ] [ -open-item xxx ] ";
 }
 
 sub description {
@@ -130,7 +130,7 @@ App::Cme::Command::edit - Edit the configuration of an application
 
 =head1 VERSION
 
-version 1.007
+version 1.008
 
 =head1 SYNOPSIS
 
