@@ -10,7 +10,7 @@
 # ABSTRACT: Modify the configuration of an application
 
 package App::Cme::Command::modify ;
-$App::Cme::Command::modify::VERSION = '1.007';
+$App::Cme::Command::modify::VERSION = '1.008';
 use strict;
 use warnings;
 use 5.10.1;
@@ -25,7 +25,7 @@ sub validate_args {
     my ($self, $opt, $args) = @_;
     $self->process_args($opt,$args);
     $self->usage_error("No modification instructions given on command line")
-        unless @$args;
+        unless @$args or $opt->{save};
 }
 
 sub opt_spec {
@@ -52,6 +52,9 @@ sub execute {
 
     my ($model, $inst, $root) = $self->init_cme($opt,$args);
 
+    # needed to create write_back subs
+    $root->dump_tree() if $opt->{save} and not @$args;
+
     $root->load("@$args");
 
     $self->save($inst,$opt) ;
@@ -71,7 +74,7 @@ App::Cme::Command::modify - Modify the configuration of an application
 
 =head1 VERSION
 
-version 1.007
+version 1.008
 
 =head1 SYNOPSIS
 
