@@ -10,7 +10,7 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.007';
+$App::Cme::Common::VERSION = '1.008';
 use strict;
 use warnings;
 use 5.10.1;
@@ -53,7 +53,7 @@ sub process_args {
     my $application = shift @$args;
 
     my $root_model = $appli_map->{$application};
-    $root_model ||= $application if $opt->{try_application_as_model};
+    $root_model ||= $application if $opt->{try_app_as_model};
     say "cme: using $root_model model" unless $opt->{quiet};
 
     Config::Model::Exception::Any->Trace(1) if $opt->{trace};
@@ -224,7 +224,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.007
+version 1.008
 
 =head1 SYNOPSIS
 
